@@ -1127,6 +1127,68 @@ sub DeleteDistributionList {
 }
 
 
+sub GrantRight {
+    my ($self, $body, $header) = @_;
+    die "GrantRight must be called as object method (\$self is <$self>)" if not blessed($self);
+    return $self->SUPER::call({
+        operation => 'GrantRight',
+        soap_action => 'urn:zimbraAdmin/GrantRight',
+        style => 'document',
+        body => {
+            
+
+           'use'            => 'literal',
+            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
+            encodingStyle   => '',
+            parts           =>  [qw( ZCS::Admin::Elements::GrantRightRequest )],
+        },
+        header => {
+            
+
+
+           'use' => 'literal',
+            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
+            encodingStyle => '',
+            parts => [qw( ZCS::Admin::Elements::context )],
+        },
+        headerfault => {
+            
+        }
+    }, $body, $header);
+}
+
+
+sub RevokeRight {
+    my ($self, $body, $header) = @_;
+    die "RevokeRight must be called as object method (\$self is <$self>)" if not blessed($self);
+    return $self->SUPER::call({
+        operation => 'RevokeRight',
+        soap_action => 'urn:zimbraAdmin/RevokeRight',
+        style => 'document',
+        body => {
+            
+
+           'use'            => 'literal',
+            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
+            encodingStyle   => '',
+            parts           =>  [qw( ZCS::Admin::Elements::RevokeRightRequest )],
+        },
+        header => {
+            
+
+
+           'use' => 'literal',
+            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
+            encodingStyle => '',
+            parts => [qw( ZCS::Admin::Elements::context )],
+        },
+        headerfault => {
+            
+        }
+    }, $body, $header);
+}
+
+
 
 
 1;
@@ -1183,6 +1245,8 @@ ZCS::Admin::Interfaces::Admin::AdminSoap12 - SOAP Interface for the Admin Web Se
  $response = $interface->GetDistributionList();
  $response = $interface->CreateDistributionList();
  $response = $interface->DeleteDistributionList();
+ $response = $interface->GrantRight();
+ $response = $interface->RevokeRight();
 
 
 
@@ -1641,10 +1705,36 @@ Returns a L<ZCS::Admin::Elements::DeleteDistributionListResponse|ZCS::Admin::Ele
   },,
  );
 
+=head3 GrantRight
+
+
+
+Returns a L<ZCS::Admin::Elements::GrantRightResponse|ZCS::Admin::Elements::GrantRightResponse> object.
+
+ $response = $interface->GrantRight( {
+    target => ,
+    grantee => ,
+    right => ,
+  },,
+ );
+
+=head3 RevokeRight
+
+
+
+Returns a L<ZCS::Admin::Elements::RevokeRightResponse|ZCS::Admin::Elements::RevokeRightResponse> object.
+
+ $response = $interface->RevokeRight( {
+    target => ,
+    grantee => ,
+    right => ,
+  },,
+ );
+
 
 
 =head1 AUTHOR
 
-Generated by SOAP::WSDL on Sat Jan 15 12:29:44 2011
+Generated by SOAP::WSDL on Fri Oct 21 15:05:29 2011
 
 =cut
