@@ -25,8 +25,9 @@ our $typemap_1 = {
                'AuthRequest/account' => 'ZCS::Admin::Types::Account',
                'DeleteAccountResponse' => 'ZCS::Admin::Elements::DeleteAccountResponse',
                'GetDistributionListResponse' => 'ZCS::Admin::Elements::GetDistributionListResponse',
-               'context/dl' => 'ZCS::Admin::Types::DlSpecifier',
+               'context/dl' => 'ZCS::Admin::Types::GetDlSpecifier',
                'CheckPasswordStrengthRequest/password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'GrantRightRequest/grantee' => 'ZCS::Admin::Types::Grantee',
                'DisableArchiveRequest/account' => 'ZCS::Admin::Types::GetAccountSpecifier',
                'CreateDomainResponse' => 'ZCS::Admin::Elements::CreateDomainResponse',
                'SearchDirectoryResponse/alias' => 'ZCS::Admin::Types::Alias',
@@ -48,13 +49,16 @@ our $typemap_1 = {
                'GetServerRequest/server' => 'ZCS::Admin::Types::GetServerSpecifier',
                'GetAccountInfoResponse/publicMailURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'CreateAccountResponse/account/a' => 'ZCS::Admin::Types::ItemAttribute',
+               'GrantRightRequest' => 'ZCS::Admin::Elements::GrantRightRequest',
                'ModifyCosResponse/cos/a' => 'ZCS::Admin::Types::CosItemAttribute',
                'RenameAccountResponse/account/a' => 'ZCS::Admin::Types::ItemAttribute',
                'RenameAccountRequest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'GetAccountMembershipResponse' => 'ZCS::Admin::Elements::GetAccountMembershipResponse',
                'Fault/detail/Error/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'DeleteDistributionListRequest' => 'ZCS::Admin::Elements::DeleteDistributionListRequest',
+               'RevokeRightRequest' => 'ZCS::Admin::Elements::RevokeRightRequest',
                'GetAllAccountsRequest/server' => 'ZCS::Admin::Types::GetServerSpecifier',
+               'RevokeRightResponse' => 'ZCS::Admin::Elements::RevokeRightResponse',
                'RenameCosRequest' => 'ZCS::Admin::Elements::RenameCosRequest',
                'AuthResponse/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'CreateDomainResponse/domain' => 'ZCS::Admin::Types::Domain',
@@ -102,12 +106,14 @@ our $typemap_1 = {
                'DelegateAuthRequest' => 'ZCS::Admin::Elements::DelegateAuthRequest',
                'GetAllDomainsRequest' => 'ZCS::Admin::Elements::GetAllDomainsRequest',
                'EnableArchiveResponse' => 'ZCS::Admin::Elements::EnableArchiveResponse',
+               'RevokeRightRequest/target' => 'ZCS::Admin::Types::GrantTarget',
                'SearchDirectoryResponse/dl' => 'ZCS::Admin::Types::Dl',
                'GetDomainResponse/domain/a' => 'ZCS::Admin::Types::ItemAttribute',
                'ModifyAccountRequest' => 'ZCS::Admin::Elements::ModifyAccountRequest',
                'SearchDirectoryResponse/cos' => 'ZCS::Admin::Types::Cos',
                'CreateCosRequest' => 'ZCS::Admin::Elements::CreateCosRequest',
                'EnableArchiveRequest' => 'ZCS::Admin::Elements::EnableArchiveRequest',
+               'GrantRightResponse' => 'ZCS::Admin::Elements::GrantRightResponse',
                'RemoveAccountAliasRequest' => 'ZCS::Admin::Elements::RemoveAccountAliasRequest',
                'AddAccountAliasResponse' => 'ZCS::Admin::Elements::AddAccountAliasResponse',
                'GetAllCosRequest' => 'ZCS::Admin::Elements::GetAllCosRequest',
@@ -140,6 +146,7 @@ our $typemap_1 = {
                'GetAccountInfoResponse/adminSoapURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'SearchDirectoryResponse/domain' => 'ZCS::Admin::Types::Domain',
                'GetAllServersResponse' => 'ZCS::Admin::Elements::GetAllServersResponse',
+               'RevokeRightRequest/grantee' => 'ZCS::Admin::Types::Grantee',
                'ModifyDomainResponse' => 'ZCS::Admin::Elements::ModifyDomainResponse',
                'CreateDistributionListResponse' => 'ZCS::Admin::Elements::CreateDistributionListResponse',
                'CreateCosRequest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -160,8 +167,10 @@ our $typemap_1 = {
                'CreateAccountResponse' => 'ZCS::Admin::Elements::CreateAccountResponse',
                'Fault/detail' => 'ZCS::Admin::Types::FaultDetail',
                'CreateAccountRequest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'RevokeRightRequest/right' => 'ZCS::Admin::Types::Right',
                'GetAllDomainsResponse/domain/a' => 'ZCS::Admin::Types::ItemAttribute',
                'DeleteCosRequest' => 'ZCS::Admin::Elements::DeleteCosRequest',
+               'GrantRightRequest/target' => 'ZCS::Admin::Types::GrantTarget',
                'PurgeMovedMailboxResponse/mbox' => 'ZCS::Admin::Types::PurgeMovedMailboxResult',
                'ModifyDomainRequest' => 'ZCS::Admin::Elements::ModifyDomainRequest',
                'ModifyAccountRequest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -214,7 +223,8 @@ our $typemap_1 = {
                'SearchDirectoryRequest/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
                'Fault/detail/Error' => 'ZCS::Admin::Types::FaultDetailError',
                'GetAllCosResponse/cos' => 'ZCS::Admin::Types::Cos',
-               'GetAccountInfoResponse/soapURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
+               'GetAccountInfoResponse/soapURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
+               'GrantRightRequest/right' => 'ZCS::Admin::Types::Right'
              };
 ;
 
